@@ -84,6 +84,13 @@ class ParticipantUnfitError(ParticipationError):
     """
 
 
+class ImproperlyConfiguredError(ParticipationError):
+    """
+    Error to return if signup cannot be performed for
+    technical or configuration reasons.
+    """
+
+
 def prevent_getting_participant_from_request_user(request):
     """
     To prevent plugin authors from accessing the participant using request.user, the SignupView
@@ -139,7 +146,6 @@ class BaseParticipationForm(forms.ModelForm):
 
     def __init__(self, *args, **kwargs):
         instance = kwargs["instance"]
-        self.shift = getattr(self, "shift", instance.shift)
         kwargs["initial"] = {
             **kwargs.get("initial", {}),
             "individual_start_time": instance.individual_start_time or self.shift.start_time,
@@ -694,8 +700,15 @@ class BaseSignupMethod:
         {% include shift.signup_method %}
         By default, this loads `shift_state_template_name` and renders it using context from `get_shift_state_context_data`.
         """
-        with context.update(self.get_shift_state_context_data(context.request)):
-            return get_template(self.shift_state_template_name).template.render(context)
+        try:
+            with context.update(self.get_shift_state_context_data(context.request)):
+                return get_template(self.shift_state_template_name).template.render(context)
+        except Exception as e:  # pylint: disable=broad-except
+            logger.exception(f"Shift #{self.shift.pk} state render failed")
+            with context.update(dict(exception_message=getattr(e, "message", None))):
+                return get_template("core/fragments/signup_method_missing.html").template.render(
+                    context
+                )
 
     def get_shift_state_context_data(self, request, **kwargs):
         """
@@ -716,13 +729,6 @@ class BaseSignupMethod:
             )
         return kwargs
 
-    def render_shift_state(self, context):
-        """
-        Render html that will be shown in the shift info box.
-        Use it to inform about the current state of the shift and participations.
-        """
-        return ""
-
     def get_participation_display(self):
         """
         Returns a displayable representation of participation that can be rendered into a table (e.g. for pdf export).
@@ -749,7 +755,7 @@ class BaseSignupMethod:
         return template
 
 
-@dataclasses.dataclass()
+@dataclasses.dataclass(frozen=True)
 class SignupStats:
     requested_count: int
     confirmed_count: int
