@@ -3,12 +3,23 @@ import operator
 from functools import reduce
 
 from django import template
+from django.urls import reverse
 from django.utils import timezone
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
 
 from ephios.core.models import AbstractParticipation, EventType, LocalParticipation, UserProfile
-from ephios.core.signals import register_event_bulk_action
+from ephios.core.signals import (
+    event_info,
+    homepage_info,
+    register_event_action,
+    register_event_bulk_action,
+    shift_info,
+)
+from ephios.core.signup.fallback import (
+    catch_signup_method_fails,
+    get_signup_method_failed_error_list,
+)
 from ephios.core.views.signup import request_to_participant
 from ephios.extra.colors import get_eventtype_color_style
 
@@ -63,21 +74,19 @@ def setvar(value=None):
 
 
 @register.filter(name="can_sign_up")
+@catch_signup_method_fails(default=False)
 def can_sign_up(request, shift):
     return shift.signup_method.can_sign_up(request_to_participant(request))
 
 
 @register.filter(name="can_customize_signup")
+@catch_signup_method_fails(default=False)
 def can_customize_signup(request, shift):
     return shift.signup_method.can_customize_signup(request_to_participant(request))
 
 
-@register.filter(name="render_shift_state")
-def render_shift_state(request, shift):
-    return shift.signup_method.render_shift_state(request)
-
-
 @register.filter(name="signup_errors")
+@catch_signup_method_fails(default=get_signup_method_failed_error_list)
 def signup_errors(request, shift):
     return set(
         shift.signup_method.get_signup_errors(request_to_participant(request))
@@ -86,6 +95,7 @@ def signup_errors(request, shift):
 
 
 @register.filter(name="can_decline")
+@catch_signup_method_fails(default=False)
 def can_decline(request, shift):
     return shift.signup_method.can_decline(request_to_participant(request))
 
@@ -144,3 +154,34 @@ def eventtype_colors():
 @register.filter(name="color_css")
 def eventtype_color_css(eventtype):
     return get_eventtype_color_style(eventtype)
+
+
+@register.simple_tag(name="event_plugin_content")
+def event_plugin_content(event, request):
+    results = event_info.send(None, event=event, request=request)
+    return list(map(lambda item: mark_safe(item[1]), results))
+
+
+@register.simple_tag(name="shift_plugin_content")
+def shift_plugin_content(shift, request):
+    results = shift_info.send(None, shift=shift, request=request)
+    return list(map(lambda item: mark_safe(item[1]), results))
+
+
+@register.simple_tag(name="homepage_plugin_content")
+def homepage_plugin_content(request):
+    results = homepage_info.send(None, request=request)
+    return list(map(lambda item: mark_safe(item[1]), results))
+
+
+@register.simple_tag(name="event_plugin_actions")
+def event_plugin_actions(event):
+    html = ""
+    for _, actions in register_event_action.send(None):
+        html += "".join(
+            [
+                f"<li><a class='dropdown-item' href='{reverse(action['url'], kwargs=dict(pk=event.id))}'><span class='fas {action['icon']}'></span> {action['label']}</a></li>"
+                for action in actions
+            ]
+        )
+    return mark_safe(html)
