@@ -90,7 +90,7 @@ urlpatterns = [
     ),
     path("events/<int:pk>/pdf/", pdf.EventDetailPDFView.as_view(), name="event_detail_pdf"),
     path(
-        "events/<int:pk>/copy",
+        "events/<int:pk>/copy/",
         EventCopyView.as_view(),
         name="event_copy",
     ),
@@ -105,7 +105,7 @@ urlpatterns = [
         name="event_list_past",
     ),
     path(
-        "events/delete",
+        "events/delete/",
         EventBulkDeleteView.as_view(),
         name="event_bulk_delete",
     ),
@@ -146,7 +146,7 @@ urlpatterns = [
     ),
     path("calendar/<str:calendar_token>/", user_event_feed_view, name="user_event_feed"),
     path(
-        "extra/rruleoccurrence",
+        "extra/rruleoccurrence/",
         RRuleOccurrenceView.as_view(),
         name="rrule_occurrences",
     ),
@@ -169,31 +169,31 @@ urlpatterns = [
     ),
     path("profile/", ProfileView.as_view(), name="profile"),
     path(
-        "profile/notifications",
+        "profile/notifications/",
         UserProfileNotificationsView.as_view(),
         name="profile_notifications",
     ),
     path("groups/", GroupListView.as_view(), name="group_list"),
-    path("groups/<int:pk>/edit", GroupUpdateView.as_view(), name="group_edit"),
-    path("groups/<int:pk>/delete", GroupDeleteView.as_view(), name="group_delete"),
-    path("groups/create", GroupCreateView.as_view(), name="group_add"),
+    path("groups/<int:pk>/edit/", GroupUpdateView.as_view(), name="group_edit"),
+    path("groups/<int:pk>/delete/", GroupDeleteView.as_view(), name="group_delete"),
+    path("groups/create/", GroupCreateView.as_view(), name="group_add"),
     path(
         "users/",
         UserProfileListView.as_view(),
         name="userprofile_list",
     ),
     path(
-        "users/<int:pk>/edit",
+        "users/<int:pk>/edit/",
         UserProfileUpdateView.as_view(),
         name="userprofile_edit",
     ),
     path(
-        "users/<int:pk>/delete",
+        "users/<int:pk>/delete/",
         UserProfileDeleteView.as_view(),
         name="userprofile_delete",
     ),
     path(
-        "users/<int:pk>/password_reset",
+        "users/<int:pk>/password_reset/",
         UserProfilePasswordResetView.as_view(),
         name="userprofile_password_reset",
     ),
@@ -203,17 +203,17 @@ urlpatterns = [
         name="userprofile_create",
     ),
     path(
-        "users/<int:pk>",
+        "users/<int:pk>/",
         UserProfileDetailView.as_view(),
         name="userprofile_detail",
     ),
     path(
-        "consequences/<int:pk>/edit",
+        "consequences/<int:pk>/edit/",
         ConsequenceUpdateView.as_view(),
         name="consequence_edit",
     ),
     path(
-        "profile/requestworkinghour",
+        "profile/requestworkinghour/",
         WorkingHourRequestView.as_view(),
         name="request_workinghour",
     ),
@@ -222,7 +222,7 @@ urlpatterns = [
     path("serviceworker.js", serviceworker, name="pwa_serviceworker"),
     path("offline/", offline, name="pwa_offline"),
     path(
-        "events/list_type_setting",
+        "events/list_type_setting/",
         EventListTypeSettingView.as_view(),
         name="event_list_type_setting",
     ),
