@@ -1,4 +1,3 @@
-import functools
 import json
 from calendar import _nextmonth, _prevmonth
 from datetime import datetime, timedelta
@@ -40,7 +39,11 @@ from ephios.core.services.notifications.types import (
     NewEventNotification,
 )
 from ephios.core.signals import event_forms
-from ephios.extra.mixins import CanonicalSlugDetailMixin, CustomPermissionRequiredMixin
+from ephios.extra.mixins import (
+    CanonicalSlugDetailMixin,
+    CustomPermissionRequiredMixin,
+    PluginFormMixin,
+)
 from ephios.extra.permissions import get_groups_with_perms
 
 
@@ -93,29 +96,7 @@ class EventDetailView(CustomPermissionRequiredMixin, CanonicalSlugDetailMixin, D
         return base.prefetch_related("shifts", "shifts__participations")
 
 
-class EventEditMixin:
-    @functools.cached_property
-    def plugin_forms(self):
-        forms = []
-        for __, resp in event_forms.send(sender=None, event=self.object, request=self.request):
-            forms.extend(resp)
-        return forms
-
-    def get_context_data(self, **kwargs):
-        kwargs["plugin_forms"] = self.plugin_forms
-        return super().get_context_data(**kwargs)
-
-    def is_valid(self, form):
-        return form.is_valid() and all(plugin_form.is_valid() for plugin_form in self.plugin_forms)
-
-    def form_valid(self, form):
-        response = super().form_valid(form)
-        for plugin_form in self.plugin_forms:
-            plugin_form.save()
-        return response
-
-
-class EventUpdateView(CustomPermissionRequiredMixin, EventEditMixin, UpdateView):
+class EventUpdateView(CustomPermissionRequiredMixin, PluginFormMixin, UpdateView):
     model = Event
     queryset = Event.all_objects.all()
     permission_required = "core.change_event"
@@ -132,8 +113,11 @@ class EventUpdateView(CustomPermissionRequiredMixin, EventEditMixin, UpdateView)
             return self.form_valid(form)
         return self.form_invalid(form)
 
+    def get_plugin_forms(self):
+        return event_forms.send(sender=None, event=self.object, request=self.request)
 
-class EventCreateView(CustomPermissionRequiredMixin, EventEditMixin, CreateView):
+
+class EventCreateView(CustomPermissionRequiredMixin, PluginFormMixin, CreateView):
     template_name = "core/event_form.html"
     permission_required = "core.add_event"
     accept_object_perms = False
@@ -166,6 +150,9 @@ class EventCreateView(CustomPermissionRequiredMixin, EventEditMixin, CreateView)
     def get_success_url(self):
         return reverse("core:event_createshift", kwargs={"pk": self.object.pk})
 
+    def get_plugin_forms(self):
+        return event_forms.send(sender=None, event=self.object, request=self.request)
+
 
 class EventActivateView(CustomPermissionRequiredMixin, SingleObjectMixin, View):
     permission_required = "core.add_event"
